@@ -951,3 +951,12 @@ class ResourceDoesNotExist(cfy_exc.NonRecoverableError):
                    'to true'.format(key=create_if_missing_key)
         if not PY2:
             super().__init__(msg, *args, **kwargs)
+
+
+@with_rest_client
+def get_cloudify_version(rest_client):
+    version = rest_client.manager.get_version()['version']
+    cloudify_version = re.findall('(\\d+.\\d+)', version)[0]
+    ctx_from_import.logger.debug('cloudify_version: {}'
+                                 .format(cloudify_version))
+    return float(cloudify_version)
